﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;
using Telerik.Windows.Controls.TreeView;
using Telerik.Windows.Controls.DragDrop;
using System.Collections;

namespace SL.DragDropFriendlyListBox
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            this.DataContext = new MainViewModel();
            DestinationBox.DataContext = new MainViewModel();

            RadDragAndDropManager.AddDragInfoHandler(this.SourceBox, SourceBox_DragInfo);
            RadDragAndDropManager.AddDropInfoHandler(this.DestinationBox, DestinationBox_DropInfo);
        }

        private void SourceBox_DragInfo(object sender, Telerik.Windows.Controls.DragDrop.DragDropEventArgs e)
        {
            if (!(e.Options.DragCue is TreeViewDragCue))
            {
                var draggedItems = ((ListBox)sender).SelectedItems.OfType<object>().ToList();
                var dragCue = new TreeViewDragCue() { ItemsSource = draggedItems };
                dragCue.DisplayMemberPath = "UserName";
                dragCue.DragTooltipVisibility = Visibility.Collapsed;

                e.Options.DragCue = dragCue;
                e.Options.Payload = draggedItems;
            }

            if (e.Options.Status == DragStatus.DragComplete && e.Options.Payload is IList)
            {
                var itemsSource = ((ListBox)sender).ItemsSource as IList;

                foreach (var item in ((IList)e.Options.Payload))
                {
                    itemsSource.Remove(item);
                }
            }
        }

        private void DestinationBox_DropInfo(object sender, Telerik.Windows.Controls.DragDrop.DragDropEventArgs e)
        {
            if (e.Options.Status == DragStatus.DropComplete && e.Options.Payload is IList)
            {
                var itemsSource = ((ListBox)sender).ItemsSource as IList;

                foreach (var item in ((IList)e.Options.Payload))
                {
                    itemsSource.Add(item);
                }
            }
        }
    }

        
    public class User : INotifyPropertyChanged
    {
        private int id;

        public int Id
        {
            get
            {
                return id;
            }
            set
            {
                id = value;
                this.OnPropertyChanged("Id");
            }
        }

        private string userName;

        public string UserName
        {
            get
            {
                return userName;
            }
            set
            {
                userName = value;
                this.OnPropertyChanged("UserName");
            }
        }

        private DateTime lastLoginDate;

        public DateTime LastLoginDate
        {
            get
            {
                return lastLoginDate;
            }
            set
            {
                lastLoginDate = value;
                this.OnPropertyChanged("LastLoginDate");
            }
        }


        private bool active;

        public bool Active
        {
            get
            {
                return active;
            }
            set
            {
                active = value;
                this.OnPropertyChanged("Active");
            }
        }


        private bool approved;

        public bool Approved
        {
            get
            {
                return approved;
            }
            set
            {
                approved = value;
                this.OnPropertyChanged("Approved");
            }
        }


        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }

    public class MainViewModel
    {
        private ObservableCollection<User> data;

        public ObservableCollection<User> Data
        {
            get { return data; }
            set { data = value; }
        }

        public MainViewModel()
        {
            GenerateData(10);
        }

        private void GenerateData(int c)
        {
            this.data = new ObservableCollection<User>((
                from p in Enumerable.Range(0, c)
                select new User
                {
                    Id = p,
                    Active = p % 2 == 0,
                    Approved = p % 3 == 0,
                    LastLoginDate = DateTime.Now.AddDays(-p),
                    UserName = "Display UserName " + p
                }).ToList());
        }

    }
      
}
